local SM = AceLibrary("SharedMedia-1.0")
local Graph = AceLibrary("Graph-1.0")

local me={}

function me:SetColorRow(name, color, changeFunc)
	self.Text:SetText(name)
	self.Background:SetVertexColor(color[1],color[2],color[3])
	self.Key:SetVertexColor(color[1],color[2],color[3])
end

function me:CreateColorRow(parent)
	local theFrame=CreateFrame("Frame",nil,parent)

	theFrame:SetWidth(196)
	theFrame:SetHeight(13)

	theFrame.Background=theFrame:CreateTexture(nil,"BACKGROUND")
	theFrame.Background:SetAllPoints(theFrame)
	theFrame.Background:SetTexture(1,1,1,0.3)
	theFrame.Background:Hide()

	theFrame.Key=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Key:SetHeight(13)
	theFrame.Key:SetWidth(13)
	theFrame.Key:SetPoint("LEFT",theFrame,"LEFT")
	theFrame.Key:SetTexture(1,1,1)

	theFrame.Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Text:SetPoint("LEFT",theFrame,"LEFT",16,0)

	theFrame:EnableMouse(true)
	theFrame:SetScript("OnEnter",function() theFrame.Background:Show() end)
	theFrame:SetScript("OnLeave",function() theFrame.Background:Hide() end)
	theFrame.SetRow=me.SetColorRow

	return theFrame
end

function me:CreateColorSelection(parent)
	me.ColorOptions=CreateFrame("Frame",nil,parent)

	local theFrame=me.ColorOptions

	theFrame:SetHeight(200)
	theFrame:SetWidth(200)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",600,-34)

	theFrame.Rows={}

	for i=1,14 do
		theFrame.Rows[i]=me:CreateColorRow(theFrame)
		theFrame.Rows[i]:SetRow("Row "..i,{math.random(),math.random(),math.random()})
		theFrame.Rows[i]:SetPoint("TOP",theFrame,"TOP",0,-2-(i-1)*14)
	end
end

function me:CreateIconFrame(parent,texture,title,text)
	local theFrame=CreateFrame("Frame",nil,parent)
	theFrame:SetWidth(18)
	theFrame:SetHeight(18)

	theFrame.texture=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.texture:SetAllPoints(theFrame)
	theFrame.texture:SetTexture(texture)
	theFrame.title=title
	theFrame.text=text

	theFrame:SetScript("OnEnter",function()
					GameTooltip:SetOwner(theFrame, "ANCHOR_TOPRIGHT")
					GameTooltip:ClearLines()
					GameTooltip:AddLine(theFrame.title)
					GameTooltip:AddLine(theFrame.text,1,1,1,true)
					GameTooltip:Show()
				     end)
	theFrame:SetScript("OnLeave",function() GameTooltip:Hide() end)

	theFrame:EnableMouse()
	theFrame:Show()

	return theFrame
end

function me:ConfigureCheckbox(check)
	check:SetWidth(20)
	check:SetHeight(20)
	check:SetScript("OnClick",function () if this:GetChecked() then this:SetChecked(true) else this:SetChecked(false) end end)
	check:SetNormalTexture("Interface\\Buttons\\UI-CheckBox-Up")
	check:SetPushedTexture("Interface\\Buttons\\UI-CheckBox-Down")
	check:SetDisabledCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check-Disabled")
	check:SetCheckedTexture("Interface\\Buttons\\UI-CheckBox-Check")
	check:SetHighlightTexture("Interface\\Buttons\\UI-CheckBox-Highlight")
end

function me:CreateFilterRow(parent,label,header)
	local theFrame=CreateFrame("Frame",nil,parent)

	theFrame:SetWidth(196)
	theFrame:SetHeight(16)
	
	theFrame.Label=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	if not header then
		theFrame.Label:SetTextColor(1,1,1,1)
	end
	theFrame.Label:SetText(" "..label)
	theFrame.Label:SetPoint("LEFT",theFrame,"LEFT",0,0)

	theFrame.ShowData=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ShowData)

	theFrame.RecordData=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.RecordData)
	theFrame.RecordData:SetScript("OnClick",function () if this:GetChecked() then this:SetChecked(true);theFrame.RecordTime:Enable();theFrame.TrackDeaths:Enable();theFrame.TrackBuffs:Enable() else this:SetChecked(false);theFrame.RecordTime:Disable();theFrame.TrackDeaths:Disable();theFrame.TrackBuffs:Disable() end end)


	theFrame.RecordTime=CreateFrame("CheckButton",nil,theFrame)	
	me:ConfigureCheckbox(theFrame.RecordTime)

	theFrame.TrackDeaths=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.TrackDeaths)

	theFrame.TrackBuffs=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.TrackBuffs)


	theFrame.ShowData:SetPoint("RIGHT",theFrame.RecordData,"LEFT",0,0)
	theFrame.RecordData:SetPoint("RIGHT",theFrame.RecordTime,"LEFT",0,0)
	theFrame.RecordTime:SetPoint("RIGHT",theFrame.TrackDeaths,"LEFT",0,0)
	theFrame.TrackDeaths:SetPoint("RIGHT",theFrame.TrackBuffs,"LEFT",0,0)
	theFrame.TrackBuffs:SetPoint("RIGHT",theFrame,"RIGHT",-1,0)

	theFrame.ShowData:Show()
	theFrame.RecordData:Show()
	theFrame.RecordTime:Show()
	theFrame.TrackDeaths:Show()
	theFrame.TrackBuffs:Show()

	return theFrame
end

function me:SetupFilterOptions(parent)
	me.FilterOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.FilterOptions

	theFrame:SetHeight(196)
	theFrame:SetWidth(196)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",2,-34)

	theFrame.Title_Show=me:CreateIconFrame(theFrame,"Interface/Icons/INV_Misc_Eye_01","Show","Is this shown in the main window?")
	theFrame.Title_Data=me:CreateIconFrame(theFrame,"Interface/Icons/INV_Misc_Note_02","Record Data","Whether data is recorded for this type")
	theFrame.Title_Time=me:CreateIconFrame(theFrame,"Interface/Icons/INV_Misc_PocketWatch_02","Record Time Data","Whether time data is recorded for this type (used for graphs can be a |cffff2020memory hog|r if you are concerned about memory)")
	theFrame.Title_Deaths=me:CreateIconFrame(theFrame,"Interface/Icons/Ability_Creature_Cursed_02","Record Deaths","Records when deaths occur and the past few actions involving this type")
	theFrame.Title_Buffs=me:CreateIconFrame(theFrame,"Interface/Icons/Ability_Warrior_SavageBlow","Record Buffs/Debuffs","Records the times and applications of buff/debuffs on this type")
	
	theFrame.Title_Show:SetPoint("RIGHT",theFrame.Title_Data,"LEFT",-2,0)
	theFrame.Title_Data:SetPoint("RIGHT",theFrame.Title_Time,"LEFT",-2,0)
	theFrame.Title_Time:SetPoint("RIGHT",theFrame.Title_Deaths,"LEFT",-2,0)
	theFrame.Title_Deaths:SetPoint("RIGHT",theFrame.Title_Buffs,"LEFT",-2,0)
	theFrame.Title_Buffs:SetPoint("TOPRIGHT",theFrame,"TOPRIGHT",-2,-2)

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("Filters")
	theFrame.Title:SetPoint("TOPLEFT",theFrame,"TOPLEFT",2,-4)



	theFrame.Filters={}
	local Filters=theFrame.Filters

	theFrame.TitlePlayers=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.TitlePlayers:SetText(" Players")
	theFrame.TitlePlayers:SetPoint("TOPLEFT",theFrame,"TOPLEFT",0,-26)

	Filters.Self=me:CreateFilterRow(theFrame,"  Self")
	Filters.Self:SetPoint("TOPLEFT",theFrame.TitlePlayers,"BOTTOMLEFT",0,-1)

	Filters.Grouped=me:CreateFilterRow(theFrame,"  Grouped")
	Filters.Grouped:SetPoint("TOPLEFT",Filters.Self,"BOTTOMLEFT",0,-1)

	Filters.Ungrouped=me:CreateFilterRow(theFrame,"  Ungrouped")
	Filters.Ungrouped:SetPoint("TOP",Filters.Grouped,"BOTTOM",0,-1)


	Filters.Pet=me:CreateFilterRow(theFrame,"Pets",true)
	Filters.Pet:SetPoint("TOP",Filters.Ungrouped,"BOTTOM",0,-1)

	theFrame.TitleMobs=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.TitleMobs:SetText(" Mobs")
	theFrame.TitleMobs:SetPoint("TOPLEFT",Filters.Pet,"BOTTOMLEFT",0,-1)

	Filters.Trivial=me:CreateFilterRow(theFrame,"  Trivial")
	Filters.Trivial:SetPoint("TOPLEFT",theFrame.TitleMobs,"BOTTOMLEFT",0,-1)

	Filters.Nontrivial=me:CreateFilterRow(theFrame,"  Non-Trivial")
	Filters.Nontrivial:SetPoint("TOP",Filters.Trivial,"BOTTOM",0,-1)

	Filters.Boss=me:CreateFilterRow(theFrame,"  Bosses")
	Filters.Boss:SetPoint("TOP",Filters.Nontrivial,"BOTTOM",0,-1)

	Filters.Unknown=me:CreateFilterRow(theFrame,"Unknown",true)
	Filters.Unknown:SetPoint("TOP",Filters.Boss,"BOTTOM",0,-1)
end


function me:SetBarTexture()
	local BarTextures=SM:List("statusbar")
	Recount:SetBarTextures(BarTextures[this.value])
	
	UIDropDownMenu_SetSelectedID(me.MiscOptions.StatusBarDropDown,this.value);
end

function me:BarTextureDropDown_Initialize()	
	local BarTextures=SM:List("statusbar")
	local LookingFor

	if not LookingFor then
		LookingFor=Recount.db.char.BarTexture
	end

	if not LookingFor then
		LookingFor="BantoBar"
	end

	for k,v in pairs(BarTextures) do
		info = {};
		info.text = v;
		info.value = k;
		info.func = me.SetBarTexture;
		UIDropDownMenu_AddButton(info);
		if v==LookingFor then
			LookingFor=k
		end
	end

	UIDropDownMenu_SetSelectedID(me.MiscOptions.StatusBarDropDown,LookingFor);
end

function me:SetSelectStatusBar(texture)
	if texture==nil then
		self:Hide()
		return
	end
	self.Text:SetText(texture)
	self.Texture:SetTexture(SM:Fetch("statusbar",texture))
	self.SetTo=texture
	self:Show()
end

function me:UpdateStatusBars()
	for _, v in pairs(me.TextureOptions.Rows) do
		if v.SetTo==Recount.db.char.BarTexture then
			v.Texture:SetVertexColor(0.2,0.9,0.2)
		else
			v.Texture:SetVertexColor(0.9,0.2,0.2)
		end
	end
end

function me:CreateSelectStatusBar(parent)
	local frame=CreateFrame("Frame",nil,parent)
	frame:SetHeight(13)
	frame:SetWidth(180)
	frame.Text=frame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	frame.Text:SetText("Temp")
	frame.Text:SetPoint("CENTER",frame,"CENTER")
	frame.Texture=frame:CreateTexture(nil,"BACKGROUND")
	frame.Texture:SetAllPoints(frame)
	frame.SetTexture=me.SetSelectStatusBar
	frame:EnableMouse()
	frame:SetScript("OnMouseDown",function() Recount:SetBarTextures(this.SetTo)
						me:UpdateStatusBars() end)
	return frame
end

function me:RefreshStatusBars()	
	local BarTextures=SM:List("statusbar")
	local size=table.getn(BarTextures)
	
	FauxScrollFrame_Update(me.TextureOptions.ScrollBar, size, 13, 12)
	local offset = FauxScrollFrame_GetOffset(me.TextureOptions.ScrollBar)
	
	for i=1,13 do
		me.TextureOptions.Rows[i]:SetTexture(BarTextures[i+offset])	
	end

	me:UpdateStatusBars()
end

function me:CreateTextureSelection(parent)
	me.TextureOptions=CreateFrame("Frame",nil,parent)

	local theFrame=me.TextureOptions
	local BarTextures=SM:List("statusbar")

	theFrame:SetHeight(200)
	theFrame:SetWidth(200)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",0,-34-200)

	--[[theFrame.Background=theFrame:CreateTexture(nil,"BACKGROUND")
	theFrame.Background:SetAllPoints(theFrame)
	theFrame.Background:SetTexture(0,0,0,0.3)]]

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("Bar Selection")
	theFrame.Title:SetPoint("TOP",theFrame,"TOP",0,-2)

	theFrame.Rows={}
	for i=1,13 do
		theFrame.Rows[i]=me:CreateSelectStatusBar(theFrame)
		theFrame.Rows[i]:SetPoint("TOP",theFrame,"TOP",-8,-i*14-2)
		theFrame.Rows[i]:SetTexture(BarTextures[i])
	end
	me:UpdateStatusBars()

	if table.getn(BarTextures)<=13 then
		for i=1,13 do
			theFrame.Rows[i]:SetWidth(196)
			theFrame.Rows[i]:SetPoint("TOP",theFrame,"TOP",0,-i*14-2)
		end
	end

	theFrame.ScrollBar=CreateFrame("SCROLLFRAME","Recount_Config_StatusBar_Scrollbar",theFrame,"FauxScrollFrameTemplate")
	theFrame.ScrollBar:SetScript("OnVerticalScroll", function() FauxScrollFrame_OnVerticalScroll(12, me.RefreshStatusBars) end)
	theFrame.ScrollBar:SetPoint("TOPLEFT",theFrame.Rows[1],"TOPLEFT")	
	theFrame.ScrollBar:SetPoint("BOTTOMRIGHT",theFrame.Rows[13],"BOTTOMRIGHT",-5,0)

	Recount:SetupScrollbar("Recount_Config_StatusBar_Scrollbar")

	me:RefreshStatusBars()
end


function me:SetSelectFont(font)
	if font==nil then
		self:Hide()
		return
	end
	self.Text:SetText(font)
	self.Text:SetFont(SM:Fetch("font",font),12)
	self.SetTo=font
	self:Show()
end

function me:UpdateFonts()
	for _, v in pairs(me.FontOptions.Rows) do
		if v.SetTo==Recount.db.char.Font then
			v.Texture:SetVertexColor(0.2,0.9,0.2)
		else
			v.Texture:SetVertexColor(0.9,0.2,0.2)
		end
	end
end

function me:CreateSelectFont(parent)
	local frame=CreateFrame("Frame",nil,parent)
	frame:SetHeight(13)
	frame:SetWidth(180)
	frame.Text=frame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	frame.Text:SetText("Temp")
	frame.Text:SetPoint("CENTER",frame,"CENTER")
	frame.Texture=frame:CreateTexture(nil,"BACKGROUND")
	frame.Texture:SetAllPoints(frame)
	frame.Texture:SetTexture(1,1,1,0.5)
	frame.SetFont=me.SetSelectFont
	frame:EnableMouse()
	frame:SetScript("OnMouseDown",function() Recount:SetFont(this.SetTo)
						me:UpdateFonts() end)
	return frame
end

function me:RefreshFonts()	
	local Fonts=SM:List("font")
	local size=table.getn(Fonts)
	
	FauxScrollFrame_Update(me.FontOptions.ScrollBar, size, 13, 12)
	local offset = FauxScrollFrame_GetOffset(me.FontOptions.ScrollBar)
	
	for i=1,13 do
		me.FontOptions.Rows[i]:SetFont(Fonts[i+offset])	
	end

	me:UpdateFonts()
end


function me:CreateFontSelection(parent)
	me.FontOptions=CreateFrame("Frame",nil,parent)

	local theFrame=me.FontOptions
	local Fonts=SM:List("font")

	theFrame:SetHeight(200)
	theFrame:SetWidth(200)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",200,-34-200)

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("Font Selection")
	theFrame.Title:SetPoint("TOP",theFrame,"TOP",0,-2)

	theFrame.Rows={}
	for i=1,13 do
		theFrame.Rows[i]=me:CreateSelectFont(theFrame)
		theFrame.Rows[i]:SetPoint("TOP",theFrame,"TOP",-8,-i*14-2)
		theFrame.Rows[i]:SetFont(Fonts[i])
	end
	me:UpdateFonts()

	if table.getn(Fonts)<=13 then
		for i=1,13 do
			theFrame.Rows[i]:SetWidth(196)
			theFrame.Rows[i]:SetPoint("TOP",theFrame,"TOP",0,-i*14-2)
		end
	end

	theFrame.ScrollBar=CreateFrame("SCROLLFRAME","Recount_Config_Fonts_Scrollbar",theFrame,"FauxScrollFrameTemplate")
	theFrame.ScrollBar:SetScript("OnVerticalScroll", function() FauxScrollFrame_OnVerticalScroll(12, me.RefreshFonts) end)
	theFrame.ScrollBar:SetPoint("TOPLEFT",theFrame.Rows[1],"TOPLEFT")	
	theFrame.ScrollBar:SetPoint("BOTTOMRIGHT",theFrame.Rows[13],"BOTTOMRIGHT",-5,0)

	Recount:SetupScrollbar("Recount_Config_Fonts_Scrollbar")

	me:RefreshFonts()
end

function me:SetupWindowOptions(parent)
	me.WindowOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.WindowOptions

	theFrame:SetHeight(200)
	theFrame:SetWidth(200)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",400,-234)

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("General Window Options")
	theFrame.Title:SetPoint("TOP",theFrame,"TOP",0,-2)

	slider = CreateFrame("Slider", "Recount_ConfigWindow_Scaling_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.ScalingSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(0.5, 1.5)
	slider:SetValueStep(0.05)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -26)
	slider:SetScript("OnValueChanged",function() Recount.db.char.Scaling=math.floor(this:GetValue()*100+0.5)/100;getglobal(this:GetName().."Text"):SetText("Window Scaling: "..Recount.db.char.Scaling);Recount:ScaleWindows(Recount.db.char.Scaling) end)
	slider:SetScript("OnMouseUp", function() me:ScaleConfigWindow(Recount.db.char.Scaling) end)
	getglobal(slider:GetName().."High"):SetText("1.5");
	getglobal(slider:GetName().."Low"):SetText("0.5");
	getglobal(slider:GetName().."Text"):SetText("Window Scaling: "..Recount.db.char.Scaling)
end


function me:SetupMiscOptions(parent)
	me.MiscOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.MiscOptions

	theFrame:SetHeight(200)
	theFrame:SetWidth(200)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",200,-34)

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("Data Options")
	theFrame.Title:SetPoint("TOP",theFrame,"TOP",0,-2)

	theFrame.Autodelete=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.Autodelete)
	theFrame.Autodelete:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-16)

	theFrame.AutodeleteText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.AutodeleteText:SetText("Autodelete Time Data")
	theFrame.AutodeleteText:SetPoint("LEFT",theFrame.Autodelete,"RIGHT",8,0)

	theFrame.AutodeleteC=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.AutodeleteC)
	theFrame.AutodeleteC:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-33)

	theFrame.AutodeleteCText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.AutodeleteCText:SetText("Autodelete Combatants")
	theFrame.AutodeleteCText:SetPoint("LEFT",theFrame.AutodeleteC,"RIGHT",8,0)


	

	local slider = CreateFrame("Slider", "Recount_ConfigWindow_TimeData_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.TimeDataSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(30, 300)
	slider:SetValueStep(5)
	slider:SetValue(30)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -66)
	slider:SetScript("OnValueChanged",function() getglobal(this:GetName().."Text"):SetText("Save Data For: "..this:GetValue().. " Minutes") end)
	getglobal(slider:GetName().."High"):SetText("300");
	getglobal(slider:GetName().."Low"):SetText("30");
	getglobal(slider:GetName().."Text"):SetText("Save Data For: "..slider:GetValue().. " Minutes")

	theFrame.CombatLogRange=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.CombatLogRange)
	theFrame.CombatLogRange:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-96)

	theFrame.CombatLogRangeText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.CombatLogRangeText:SetText("Set Combat Log Range")
	theFrame.CombatLogRangeText:SetPoint("LEFT",theFrame.CombatLogRange,"RIGHT",8,0)

	local slider = CreateFrame("Slider", "Recount_ConfigWindow_CombatLogRange_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.CombatLogRangeSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(40, 200)
	slider:SetValueStep(5)
	slider:SetValue(40)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -130)
	slider:SetScript("OnValueChanged",function() getglobal(this:GetName().."Text"):SetText("Combat Log Range: "..this:GetValue().. " Yds") end)
	getglobal(slider:GetName().."High"):SetText("200");
	getglobal(slider:GetName().."Low"):SetText("40");
	getglobal(slider:GetName().."Text"):SetText("Combat Log Range: "..slider:GetValue().. " Yds")

	theFrame.MergePets=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.MergePets)
	theFrame.MergePets:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-160)

	theFrame.MergePetsText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.MergePetsText:SetText("Merge Pets w/ Owners")
	theFrame.MergePetsText:SetPoint("LEFT",theFrame.MergePets,"RIGHT",8,0)

	theFrame.FixLog=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.FixLog)
	theFrame.FixLog:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-176)

	theFrame.FixLogText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.FixLogText:SetText("Fix Ambiguous Log Strings")
	theFrame.FixLogText:SetPoint("LEFT",theFrame.FixLog,"RIGHT",8,0)
end

function me:SetupButtonOptions(parent)
	me.ButtonOptions=CreateFrame("Frame",nil,parent)
	local theFrame=me.ButtonOptions

	theFrame:SetHeight(196)
	theFrame:SetWidth(196)
	theFrame:SetPoint("TOPLEFT",parent,"TOPLEFT",400,-34)
	--Reset
	--File
	--Config
	--Report

	theFrame.Title=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Title:SetText("Main Window Options")
	theFrame.Title:SetPoint("TOP",theFrame,"TOP",0,-2)

	theFrame.ButtonsTitle=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.ButtonsTitle:SetText("Show Buttons")
	theFrame.ButtonsTitle:SetPoint("TOP",theFrame,"TOPLEFT",100,-16)
	
	theFrame.ResetButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ResetButton)
	theFrame.ResetButton:SetPoint("TOPLEFT",theFrame,"TOPLEFT",8,-18-16)

	theFrame.Reset_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Reset_Icon:SetWidth(16)
	theFrame.Reset_Icon:SetHeight(16)
	theFrame.Reset_Icon:SetTexture("Interface\\Addons\\Recount\\Textures\\icon-reset")
	theFrame.Reset_Icon:SetPoint("LEFT",theFrame.ResetButton,"RIGHT",2,0)

	theFrame.Reset_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Reset_Text:SetText("Reset")
	theFrame.Reset_Text:SetPoint("LEFT",theFrame.Reset_Icon,"RIGHT",2,0)

	theFrame.FileButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.FileButton)
	theFrame.FileButton:SetPoint("TOP",theFrame.ResetButton,"BOTTOM",0,-2)

	theFrame.File_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.File_Icon:SetWidth(16)
	theFrame.File_Icon:SetHeight(16)
	theFrame.File_Icon:SetTexture("Interface\\Buttons\\UI-GuildButton-PublicNote-Up.blp")
	theFrame.File_Icon:SetPoint("LEFT",theFrame.FileButton,"RIGHT",2,0)

	theFrame.File_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.File_Text:SetText("File")
	theFrame.File_Text:SetPoint("LEFT",theFrame.File_Icon,"RIGHT",2,0)

	theFrame.ConfigButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ConfigButton)
	theFrame.ConfigButton:SetPoint("TOPLEFT",theFrame,"TOPLEFT",100,-18-16)

	theFrame.Config_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Config_Icon:SetWidth(16)
	theFrame.Config_Icon:SetHeight(16)
	theFrame.Config_Icon:SetTexture("Interface\\Addons\\Recount\\Textures\\icon-config")
	theFrame.Config_Icon:SetPoint("LEFT",theFrame.ConfigButton,"RIGHT",2,0)

	theFrame.Config_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Config_Text:SetText("Config")
	theFrame.Config_Text:SetPoint("LEFT",theFrame.Config_Icon,"RIGHT",2,0)

	theFrame.ReportButton=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.ReportButton)
	theFrame.ReportButton:SetPoint("TOP",theFrame.ConfigButton,"BOTTOM",0,-2)

	theFrame.Report_Icon=theFrame:CreateTexture(nil,"OVERLAY")
	theFrame.Report_Icon:SetWidth(16)
	theFrame.Report_Icon:SetHeight(16)
	theFrame.Report_Icon:SetTexture("Interface\\Buttons\\UI-GuildButton-MOTD-Up.blp")
	theFrame.Report_Icon:SetPoint("LEFT",theFrame.ReportButton,"RIGHT",2,0)

	theFrame.Report_Text=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.Report_Text:SetText("Report")
	theFrame.Report_Text:SetPoint("LEFT",theFrame.Report_Icon,"RIGHT",2,0)

	local slider = CreateFrame("Slider", "Recount_ConfigWindow_RowHeight_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.RowHeightSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(8, 24)
	slider:SetValueStep(1)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -96)
	slider:SetScript("OnValueChanged",function() getglobal(this:GetName().."Text"):SetText("Row Height: "..this:GetValue());Recount.db.char.MainWindow.RowHeight=this:GetValue();Recount:BarsChanged() end)
	getglobal(slider:GetName().."High"):SetText("24");
	getglobal(slider:GetName().."Low"):SetText("8");
	getglobal(slider:GetName().."Text"):SetText("Row Height: "..slider:GetValue())

	slider = CreateFrame("Slider", "Recount_ConfigWindow_RowSpacing_Slider", theFrame,"OptionsSliderTemplate")
	theFrame.RowSpacingSlider=slider
	slider:SetOrientation("HORIZONTAL")
	slider:SetMinMaxValues(0, 4)
	slider:SetValueStep(1)
	slider:SetWidth(180)
	slider:SetHeight(16)
	slider:SetPoint("TOP", theFrame, "TOP", 0, -130)
	slider:SetScript("OnValueChanged",function() getglobal(this:GetName().."Text"):SetText("Row Spacing: "..this:GetValue());Recount.db.char.MainWindow.RowSpacing=this:GetValue();Recount:BarsChanged() end)
	getglobal(slider:GetName().."High"):SetText("4");
	getglobal(slider:GetName().."Low"):SetText("0");
	getglobal(slider:GetName().."Text"):SetText("Row Spacing: "..slider:GetValue())

	theFrame.AutoHide=CreateFrame("CheckButton",nil,theFrame)
	me:ConfigureCheckbox(theFrame.AutoHide)
	theFrame.AutoHide:SetPoint("TOPLEFT",theFrame,"TOPLEFT",12,-160)

	theFrame.AutohideText=theFrame:CreateFontString(nil,"OVERLAY","GameFontNormal")
	theFrame.AutohideText:SetText("Autohide On Combat")
	theFrame.AutohideText:SetPoint("LEFT",theFrame.AutoHide,"RIGHT",8,0)

	
end

function me:ScaleConfigWindow(scale)
	local pointNum=me.ConfigWindow:GetNumPoints()
	local curScale=me.ConfigWindow:GetScale();
	local points={}
	for i=1,pointNum,1 do
		points[i]={};
		points[i][1], points[i][2], points[i][3], points[i][4], points[i][5]=me.ConfigWindow:GetPoint(i)
		points[i][4]=points[i][4]*curScale/scale;
		points[i][5]=points[i][5]*curScale/scale;
	end

	me.ConfigWindow:ClearAllPoints()
	for i=1,pointNum,1 do
		me.ConfigWindow:SetPoint(points[i][1],points[i][2],points[i][3],points[i][4],points[i][5]);
	end

	me.ConfigWindow:SetScale(scale)
end


function me:CreateConfigWindow()
	me.ConfigWindow=Recount:CreateFrame("Recount_ConfigWindow","Config Recount",464,600)

	local theFrame=me.ConfigWindow
	

	theFrame.SaveButton=CreateFrame("Button",nil,theFrame,"OptionsButtonTemplate")
	theFrame.SaveButton:SetWidth(90)
	theFrame.SaveButton:SetHeight(24)
	theFrame.SaveButton:SetPoint("BOTTOMRIGHT",theFrame,"BOTTOM",-2,4)
	theFrame.SaveButton:SetScript("OnClick",function() me:SaveConfig() end)
	theFrame.SaveButton:SetText("Save")

	theFrame.RevertButton=CreateFrame("Button",nil,theFrame,"OptionsButtonTemplate")
	theFrame.RevertButton:SetWidth(90)
	theFrame.RevertButton:SetHeight(24)
	theFrame.RevertButton:SetPoint("BOTTOMLEFT",theFrame,"BOTTOM",2,4)
	theFrame.RevertButton:SetScript("OnClick",function() me:LoadConfig() end)
	theFrame.RevertButton:SetText("Revert")

	me:SetupFilterOptions(theFrame)
	Graph:DrawLine(theFrame,200,32,200,433,24,{0.5,0.0,0.0,1.0},"ARTWORK")
	me:SetupMiscOptions(theFrame)
	Graph:DrawLine(theFrame,400,32,400,433,24,{0.5,0.0,0.0,1.0},"ARTWORK")

	Graph:DrawLine(theFrame,2,233,598,233,24,{0.5,0.0,0.0,1.0},"ARTWORK")
	 me:SetupButtonOptions(theFrame)
	theFrame:Hide()

	me:SetupWindowOptions(theFrame)
	me:CreateTextureSelection(theFrame)
	me:CreateFontSelection(theFrame)
	--me:CreateColorSelection(theFrame)

	--Need to add it to our window ordering system
	Recount:AddWindow(theFrame)
end

function me:LoadConfig()
	for k, v in pairs(me.FilterOptions.Filters) do
		v.ShowData:SetChecked(Recount.db.char.Filters.Show[k])
		v.RecordData:SetChecked(Recount.db.char.Filters.Data[k])
		v.RecordTime:SetChecked(Recount.db.char.Filters.TimeData[k])
		v.TrackDeaths:SetChecked(Recount.db.char.Filters.TrackDeaths[k])		
	end

	for k, v in pairs(Recount.db.char.MainWindow.Buttons) do
		me.ButtonOptions[k]:SetChecked(v)
	end

	me.ButtonOptions.RowHeightSlider:SetValue(Recount.db.char.MainWindow.RowHeight)
	me.ButtonOptions.RowSpacingSlider:SetValue(Recount.db.char.MainWindow.RowSpacing)
	me.ButtonOptions.AutoHide:SetChecked(Recount.db.char.MainWindow.AutoHide)

	me.WindowOptions.ScalingSlider:SetValue(Recount.db.char.Scaling)

	me.MiscOptions.Autodelete:SetChecked(Recount.db.char.AutoDelete)
	me.MiscOptions.AutodeleteC:SetChecked(Recount.db.char.AutoDeleteCombatants)
	me.MiscOptions.MergePets:SetChecked(Recount.db.char.MergePets)
	me.MiscOptions.TimeDataSlider:SetValue(Recount.db.char.AutoDeleteTime)
	me.MiscOptions.CombatLogRange:SetChecked(Recount.db.char.UseCombatLogRange)
	me.MiscOptions.CombatLogRangeSlider:SetValue(Recount.db.char.CombatLogRange)


	me.MiscOptions.FixLog:SetChecked(Recount.db.char.UseFixLog)


	me:ScaleConfigWindow(Recount.db.char.Scaling)
end

function me:SaveConfig()
	for k, v in pairs(me.FilterOptions.Filters) do
		Recount.db.char.Filters.Show[k]=v.ShowData:GetChecked()==1
		Recount.db.char.Filters.Data[k]=v.RecordData:GetChecked()==1
		Recount.db.char.Filters.TimeData[k]=v.RecordTime:GetChecked()==1
		Recount.db.char.Filters.TrackDeaths[k]=v.TrackDeaths:GetChecked()==1
	end

	for k, v in pairs(Recount.db.char.MainWindow.Buttons) do
		Recount.db.char.MainWindow.Buttons[k]=(me.ButtonOptions[k]:GetChecked()==1)
	end
	Recount.db.char.MainWindow.AutoHide=me.ButtonOptions.AutoHide:GetChecked()==1

	Recount.db.char.AutoDelete=me.MiscOptions.Autodelete:GetChecked()==1
	Recount.db.char.AutoDeleteCombatants=me.MiscOptions.AutodeleteC:GetChecked()==1
	Recount.db.char.AutoDeleteTime=me.MiscOptions.TimeDataSlider:GetValue()
	Recount.db.char.MergePets=me.MiscOptions.MergePets:GetChecked()==1
	Recount.db.char.UseFixLog=me.MiscOptions.FixLog:GetChecked()==1



	Recount.db.char.UseCombatLogRange=me.MiscOptions.CombatLogRange:GetChecked()==1
	Recount.db.char.CombatLogRange=me.MiscOptions.CombatLogRangeSlider:GetValue()

	if Recount.db.char.UseCombatLogRange then
		Recount:SetLogRange(Recount.db.char.CombatLogRange)
	else
		Recount:SetLogRangeDefault() 
	end


	Recount.MainWindow.DispTableSorted={}
	Recount.MainWindow.DispTableLookup={}

	Recount:SetupMainWindowButtons()
	Recount:RefreshMainWindow()
end

function Recount:ShowConfig()
	if type(me.ConfigWindow)=="nil" then
		me:CreateConfigWindow()
	end
	me:LoadConfig()
	me.ConfigWindow:Show()
end


function Recount:ConfigWindowStatus()
	if me.ConfigWindow.Below then
		below = me.ConfigWindow.Below:GetName()
	else
		below = "(nil)"
	end

	if me.ConfigWindow.Above then
		above = me.ConfigWindow.Above:GetName()
	else
		above = "(nil)"
	end

	Recount:Print(below.." Config "..above)
end

